@@ -6,6 +6,9 @@
 import collections
 import time
 import util
+import process as processing
+
+logger = processing.get_logger()
 
 WildCardMessageType = '*'
 
@@ -37,6 +40,7 @@ class MessageReceiver(object):
         if hasattr(self, method):
             return getattr(self, method)(msg)
         else:
+            logger.info("Actor %s's '%s' method wasn't found.  Message '%s' skipped" % (self, method, msg))
             return False
     def update(self, evt=None):
         pass
