@@ -100,7 +100,11 @@ def _subprocess_main(name, default_actor_class, max_tick_time, interval, server_
     assert not manager.is_main_process
     while not manager._should_quit.value:
         start = util.get_time()
-        manager.tick(max_time=max_tick_time)
+        try:
+            manager.tick(max_time=max_tick_time)
+        except Exception, e:
+            manager.log(logging.ERROR, 'process "%s" failed with: %s' % (processing.get_pid(processing.current_process()), e))
+            raise
         # we want to sleep the difference between the time it took to process and the interval desired
         _time_to_sleep = interval - (util.get_time() - start)
         if _time_to_sleep > 0.0:
